@@ -6,16 +6,17 @@
 #include "dictionaryrunner.h"
 
 #include <KLocalizedString>
+#include <QEventLoop>
 #include <QStringList>
+#include <QTimer>
 
 static const char CONFIG_TRIGGERWORD[] = "triggerWord";
 
 DictionaryRunner::DictionaryRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
     : AbstractRunner(parent, metaData, args)
 {
-    m_engine = new DictionaryMatchEngine(dataEngine(QStringLiteral("dict")), this);
+    m_engine = new DictionaryMatchEngine(m_consumer.dataEngine(QStringLiteral("dict")), this);
 
-    setSpeed(SlowSpeed);
     setPriority(LowPriority);
     setObjectName(QLatin1String("Dictionary"));
 }
@@ -35,8 +36,7 @@ void DictionaryRunner::reloadConfiguration()
     } else {
         setMatchRegex(QRegularExpression());
     }
-    setSyntaxes(QList<Plasma::RunnerSyntax>() << Plasma::RunnerSyntax(
-                    Plasma::RunnerSyntax(i18nc("Dictionary keyword", "%1:q:", m_triggerWord), i18n("Finds the definition of :q:."))));
+    setSyntaxes({Plasma::RunnerSyntax(i18nc("Dictionary keyword", "%1:q:", m_triggerWord), i18n("Finds the definition of :q:."))});
 }
 
 void DictionaryRunner::match(Plasma::RunnerContext &context)
@@ -48,7 +48,18 @@ void DictionaryRunner::match(Plasma::RunnerContext &context)
     if (query.isEmpty()) {
         return;
     }
+    QEventLoop loop;
+    QTimer::singleShot(400, &loop, [&loop]() {
+        loop.quit();
+    });
+    loop.exec();
+    if (!context.isValid()) {
+        return;
+    }
     QString returnedQuery = m_engine->lookupWord(query);
+    if (!context.isValid()) {
+        return;
+    }
 
     static const QRegExp removeHtml(QLatin1String("<[^>]*>"));
     QString definitions(returnedQuery);
@@ -84,6 +95,6 @@ void DictionaryRunner::match(Plasma::RunnerContext &context)
     context.addMatches(matches);
 }
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(DictionaryRunner, "plasma-runner-dictionary.json")
+K_PLUGIN_CLASS_WITH_JSON(DictionaryRunner, "plasma-runner-dictionary.json")
 
 #include "dictionaryrunner.moc"
