@@ -20,7 +20,6 @@ SpellCheckRunner::SpellCheckRunner(QObject *parent, const KPluginMetaData &metaD
     : Plasma::AbstractRunner(parent, metaData, args)
 {
     setObjectName(QStringLiteral("Spell Checker"));
-    setSpeed(AbstractRunner::SlowSpeed);
 }
 
 SpellCheckRunner::~SpellCheckRunner() = default;
@@ -160,10 +159,6 @@ QString SpellCheckRunner::findLang(const QStringList &terms)
 
 void SpellCheckRunner::match(Plasma::RunnerContext &context)
 {
-    if (!context.isValid()) {
-        return;
-    }
-
     const QString term = context.query();
     QString query = term;
 
@@ -249,6 +244,6 @@ QMimeData *SpellCheckRunner::mimeDataForMatch(const Plasma::QueryMatch &match)
     return result;
 }
 
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(SpellCheckRunner, "plasma-runner-spellchecker.json")
+K_PLUGIN_CLASS_WITH_JSON(SpellCheckRunner, "plasma-runner-spellchecker.json")
 
 #include "spellcheck.moc"
